# CLIME Badges

> A tool to create custom badges displaying CLIME metrics

<!-- Insert GH badges -->
<!-- Insert Zenodo badges -->

## Table of Contents

- [CLIME Badges](#clime-badges)
  - [Table of Contents](#table-of-contents)
  - [About](#about)
    - [Licensing](#licensing)
  - [How To Use](#how-to-use)
    - [Installation](#installation)

## About

The Software Systems Laboratory (SSL) CLIME Badges project is a tool to create custom badges displaying CLIME metrics.

### Licensing

This project is licensed under the BSD-3-Clause. See the [LICENSE](LICENSE) for more information.

## How To Use

### Installation

You can install the tool from PyPi with one of the following one liners:

- `pip install clime-metrics`
- `pip install clime-badges`
